"""
from collections import defaultdict
from datetime import datetime
from saberlist.BeatLeaderAPI import BeatLeaderAPI
from archive.PlaylistBuilder import PlaylistBuilder
import json
import os

import logging
logging.basicConfig(
    format='%(asctime)s %(levelname)s: %(message)s',
    datefmt='%Y-%m-%d %H:%M:%S',
    level=logging.DEBUG
)

def prompt_for_player_id(default_id='76561199407393962'):
    prompt = f"Enter player ID (press Enter for default '{default_id}'): "
    user_input = input(prompt).strip()
    return user_input if user_input else default_id

def build_difficulty_based_playlist(api, player_id, history, playlist_name, song_count=5):
    scores_data = api.get_player_scores(player_id, use_cache=True)
    all_scores = scores_data['data']
    all_scores.sort(key=lambda x: x['timepost'])
    
    difficulty_groups = defaultdict(list)
    no_stars_group = []
    for score in all_scores:
        stars = score['leaderboard']['difficulty'].get('stars')
        song_id = score['leaderboard']['song']['id']
        difficulty_name = score['leaderboard']['difficulty']['difficultyName']
        
        # Check if this song:difficulty combination is in history
        if song_id not in history or difficulty_name not in history[song_id]:
            if stars is None or stars == 0:
                no_stars_group.append(score)
            elif 0 < stars <= 3:
                difficulty_groups[0].append(score)
            elif 4 <= stars < 6:
                difficulty_groups[1].append(score)
            elif 6 <= stars < 7:
                difficulty_groups[2].append(score)
            elif stars >= 7:
                difficulty_groups[3].append(score)
    
    playlist_scores = []
    for difficulty, count in [(0, song_count), (1, song_count), (2, song_count), (3, song_count)]:
        unique_songs = {}
        for score in difficulty_groups[difficulty]:
            song_id = score['leaderboard']['song']['id']
            if song_id not in unique_songs or score['timepost'] < unique_songs[song_id]['timepost']:
                unique_songs[song_id] = score
        
        playlist_scores.extend(sorted(unique_songs.values(), key=lambda x: x['timepost'])[:count])
    
    # Update history
    for score in playlist_scores:
        song_id = score['leaderboard']['song']['id']
        difficulty_name = score['leaderboard']['difficulty']['difficultyName']
        if song_id not in history:
            history[song_id] = []
        history[song_id].append(difficulty_name)
    
    # Prepare the custom playlist
    custom_playlist = []
    for score in playlist_scores:
        custom_playlist.append({
            'song': score['leaderboard']['song'],
            'difficulty': score['leaderboard']['difficulty']
        })

    playlist_builder = PlaylistBuilder()
    playlist_file, used_cover = playlist_builder.create_player_playlist_with_random_cover(
        playlist_scores, 
        playlist_name, 
        "SaberList Tool",
        used_covers=set(history['used_covers'])
    )

    if used_cover:
        history['used_covers'].append(used_cover)
    
    return playlist_file, playlist_scores, used_cover

def saberlist_replay_bl():
    api = BeatLeaderAPI()
    player_id = prompt_for_player_id()
    player_info = api.get_player_info(player_id)

    if player_info:
        logging.info(f"Fetching score history for player: {player_info.get('name', 'N/A')}")
    
    history = load_history()
    
    timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
    playlist_name = f"star_ladder-{timestamp}"
    
    playlist_file, playlist_scores, used_cover = build_difficulty_based_playlist(api, player_id, history, playlist_name, song_count=10)
    save_history(history)

    print(f"Playlist created: {playlist_file}")
    if used_cover:
        print(f"Cover image used: {used_cover}")
    print("Playlist contents:")
    for i, score in enumerate(playlist_scores, 1):
        song = score['leaderboard']['song']
        difficulty = score['leaderboard']['difficulty']
        print(f"{i}. {song['name']} by {song['author']} (Mapper: {song['mapper']}) - {difficulty['stars']:.2f} stars - Last played: {datetime.fromtimestamp(score['timepost'])}")

if __name__ == "__main__":
    saberlist_replay_bl()
"""